@@ -162,7 +162,7 @@ class MosmixS:
 
     @staticmethod
     def load(station_id: str, url: str = 'https://opendata.dwd.de/weather/local_forecasts/mos/MOSMIX_S/all_stations/kml/MOSMIX_S_LATEST_240.kmz'):
-        logging.info("loading MOSMIX_S")
+        logging.debug("loading MOSMIX_S")
         mosmix = MosmixS(station_id)
         xml_parser = ET.XMLPullParser(['start', 'end'])
         for file_name, file_size, unzipped_chunks in stream_unzip(MosmixS.__perform_get_chunked(url)):
